/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: provider_l.h 764 2006-01-13 14:00:00Z cstim $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef AD_PROVIDER_L_H
#define AD_PROVIDER_L_H

#include <aqbanking/provider_be.h>
#include "aqdtaus_l.h"

AQDTAUS_API AB_PROVIDER *AD_Provider_new(AB_BANKING *ab);


#endif

